.. Copyright 2013-2023 Reahl Software Services (Pty) Ltd. All rights reserved.

Module reahl.domainui.bootstrap.accounts
----------------------------------------

.. automodule:: reahl.domainui.bootstrap.accounts


AccountUI
"""""""""

.. autoclass:: AccountUI
   :members:
